@@ -121,7 +121,7 @@ pub fn run(config: Config) -> Result<(), Box<dyn Error>> {
     let result: Vec<String> = search(&config.pattern, &data);
 
     if result.is_empty() {
-        println!("No match found for {} in {}", &config.pattern, &config.file);
+        return Err((format!("No match found for {} in {}", &config.pattern, &config.file)).into());
     } else {
         let (mut line_count, mut total_occurrence): (u128, u128) = (0u128, 0u128);
 
